@@ -1,12 +1,13 @@
 
 
 import pandas as pd 
-# import snowflake.connector
+import snowflake.connector
 
-from snowflake.sqlalchemy import URL
-from sqlalchemy import create_engine
+# from snowflake.sqlalchemy import URL
+# from sqlalchemy import create_engine
 from cryptography.fernet import Fernet
 
+
 from ml_processor.configuration import config
 import time
 import os
@@ -83,7 +84,7 @@ class snowflake_processor:
             connection to snowflake.
 
         """
-        
+##### connection using sqlalchemy
         # try:
         #     engine = create_engine(
         #         URL(
@@ -100,15 +101,12 @@ class snowflake_processor:
         # else:
         #     return engine
 
+##### connection using snowflake.connector
         try:
-            engine = create_engine(
-                "snowflake://{user}:{password}@{account}/{db}/{schema}?warehouse={warehouse}".format(
-                    user = self.credentials.get('username'),
-                    password = self.credentials.get('password'),
-                    account = self.credentials.get('account'),
-                    db = self.credentials.get('database'),
-                    warehouse = self.credentials.get('warehouse')
-                    )
+            engine = snowflake.connector.connect(
+                user = self.credentials.get('username'),
+                password = self.credentials.get('password'),
+                account = self.credentials.get('account'),
                 )
 
             self.logger.info(f'Connection to {self.credentials.get("account")} successful')
@@ -116,6 +114,7 @@ class snowflake_processor:
             self.logger.error('Exception occured', exc_info=True)
         else:
             return engine
+
         
     def pandas_from_sql(self, sql, conn=None, chunksize=None):
         
